@@ -1,6 +1,4 @@
 """Constants."""
-import os
-
 import jmespath
 
 PROJECT_OWNER = "andreoliwa"
@@ -20,8 +18,8 @@ SETUP_PY = "setup.py"
 SETUP_CFG = "setup.cfg"
 REQUIREMENTS_STAR_TXT = "requirements*.txt"
 PIPFILE_STAR = "Pipfile*"
-ROOT_PYTHON_FILES = ("app.py", "wsgi.py", "autoapp.py")
 MANAGE_PY = "manage.py"
+ROOT_PYTHON_FILES = ("app.py", "wsgi.py", "autoapp.py", MANAGE_PY)
 TOX_INI = "tox.ini"
 PYLINTRC = ".pylintrc"
 # Tools
@@ -52,26 +50,22 @@ ROOT_FILES = (
 ) + ROOT_PYTHON_FILES
 CONFIG_FILES = (DOT_NITPICK_TOML, PYPROJECT_TOML)
 
-SINGLE_QUOTE = "'"
-DOUBLE_QUOTE = '"'
-
-#: Special unique separator for :py:meth:`flatten()` and :py:meth:`unflatten()`,
-# to avoid collision with existing key values (e.g. the default dot separator "." can be part of a pyproject.toml key).
-SEPARATOR_FLATTEN = "$#@"
-
-#: Special unique separator for :py:meth:`nitpick.generic.quoted_split()`.
-SEPARATOR_QUOTED_SPLIT = "#$@"
-
 # Config sections and keys
-TOOL_NITPICK = "tool.nitpick"
+TOOL_KEY = "tool"
+TOOL_NITPICK_KEY = f"{TOOL_KEY}.{PROJECT_NAME}"
 
 # JMESPath expressions
-TOOL_NITPICK_JMEX = jmespath.compile(TOOL_NITPICK)
+TOOL_NITPICK_JMEX = jmespath.compile(TOOL_NITPICK_KEY)
 NITPICK_STYLES_INCLUDE_JMEX = jmespath.compile("nitpick.styles.include")
 NITPICK_MINIMUM_VERSION_JMEX = jmespath.compile("nitpick.minimum_version")
 
-#: Dot/slash is used to indicate a local style file
-SLASH = os.path.sep
-DOT_SLASH = f".{SLASH}"
+# Dot/slash is just a convention to indicate a local style file;
+# the same pair of characters should be used on Windows, even though the path separator is different
+DOT = "."
+SLASH = "/"
+DOT_SLASH = f"{DOT}{SLASH}"
 
 GIT_AT_REFERENCE = "@"
+
+# Special configurations for plugins
+DUNDER_LIST_KEYS = "__list_keys"
