@@ -1,27 +1,28 @@
 """Base class for file checkers."""
 import abc
+import fnmatch
 from functools import lru_cache
 from pathlib import Path
-from typing import Iterator, Optional, Set
+from typing import Dict, Iterator, Optional, Set, Type
 
-import jmespath
 from autorepr import autotext
 from loguru import logger
 from marshmallow import Schema
 
-from nitpick.formats import Comparison
-from nitpick.generic import search_dict
+from nitpick.blender import SEPARATOR_DOT, BaseDoc, DictBlender, search_json
+from nitpick.config import SpecialConfig
+from nitpick.constants import DUNDER_LIST_KEYS
 from nitpick.plugins.info import FileInfo
 from nitpick.typedefs import JsonDict, mypy_property
 from nitpick.violations import Fuss, Reporter, SharedViolations
 
 
-class NitpickPlugin(metaclass=abc.ABCMeta):
+class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance-attributes
     """Base class for Nitpick plugins.
 
     :param data: File information (project, path, tags).
     :param expected_config: Expected configuration for the file
-    :param fix: Flag to modify files, if the plugin supports it (default: True).
+    :param autofix: Flag to modify files, if the plugin supports it (default: True).
     """
 
     __str__, __unicode__ = autotext("{self.info.path_from_root} ({self.__class__.__name__})")
@@ -29,11 +30,11 @@ class NitpickPlugin(metaclass=abc.ABCMeta):
     filename = ""  # TODO: remove filename attribute after fixing dynamic/fixed schema loading
     violation_base_code: int = 0
 
-    #: Can this plugin modify files directly?
-    can_fix: bool = False
+    #: Can this plugin modify its files directly? Are the files fixable?
+    fixable: bool = False
 
     #: Nested validation field for this file, to be applied in runtime when the validation schema is rebuilt.
-    #: Useful when you have a strict configuration for a file type (e.g. :py:class:`nitpick.plugins.json.JSONPlugin`).
+    #: Useful when you have a strict configuration for a file type (e.g. :py:class:`nitpick.plugins.json.JsonPlugin`).
     validation_schema: Optional[Schema] = None
 
     #: Which ``identify`` tags this :py:class:`nitpick.plugins.base.NitpickPlugin` child recognises.
@@ -41,7 +42,7 @@ class NitpickPlugin(metaclass=abc.ABCMeta):
 
     skip_empty_suggestion = False
 
-    def __init__(self, info: FileInfo, expected_config: JsonDict, fix=False) -> None:
+    def __init__(self, info: FileInfo, expected_config: JsonDict, autofix=False) -> None:
         self.info = info
         self.filename = info.path_from_root
         self.reporter = Reporter(info, self.violation_base_code)
@@ -51,24 +52,43 @@ class NitpickPlugin(metaclass=abc.ABCMeta):
         # Configuration for this file as a TOML dict, taken from the style file.
         self.expected_config: JsonDict = expected_config or {}
 
-        self.fix = self.can_fix and fix
+        self.autofix = self.fixable and autofix
         # Dirty flag to avoid changing files without need
         self.dirty: bool = False
 
+        self._merge_special_configs()
+
+    def _merge_special_configs(self):
+        """Merge the predefined plugin config with the style dict to create the special config."""
+        spc = self.predefined_special_config()
+        temp_dict = spc.list_keys.from_plugin.copy()  # pylint: disable=no-member
+
+        # The user can override the default list keys (if any) by setting them on the style file.
+        # pylint: disable=assigning-non-slot,no-member
+        spc.list_keys.from_style = self.expected_config.pop(DUNDER_LIST_KEYS, None) or {}
+        temp_dict.update(DictBlender(spc.list_keys.from_style, separator=SEPARATOR_DOT).flat_dict)
+
+        flat_config = DictBlender(self.expected_config, separator=SEPARATOR_DOT).flat_dict
+
+        for key_with_pattern, parent_child_keys in temp_dict.items():
+            for expanded_key in fnmatch.filter(flat_config.keys(), key_with_pattern):
+                spc.list_keys.value[expanded_key] = parent_child_keys
+
+        self.special_config = spc
+
+    def predefined_special_config(self) -> SpecialConfig:  # pylint: disable=no-self-use
+        """Create a predefined special configuration for this plugin. Each plugin can override this method."""
+        return SpecialConfig()
+
     @mypy_property
     @lru_cache()
     def nitpick_file_dict(self) -> JsonDict:
         """Nitpick configuration for this file as a TOML dict, taken from the style file."""
-        return search_dict(f'files."{self.filename}"', self.info.project.nitpick_section, {})
-
-    @classmethod
-    def get_compiled_jmespath_filenames(cls):
-        """Return a compiled JMESPath expression for file names, using the class name as part of the key."""
-        return jmespath.compile(f"nitpick.{cls.__name__}.filenames")
+        return search_json(self.info.project.nitpick_section, f'files."{self.filename}"', {})
 
     def entry_point(self) -> Iterator[Fuss]:
         """Entry point of the Nitpick plugin."""
-        self.init()
+        self.post_init()
 
         should_exist: bool = bool(self.info.project.nitpick_files_section.get(self.filename, True))
         if self.file_path.exists() and not should_exist:
@@ -91,13 +111,17 @@ class NitpickPlugin(metaclass=abc.ABCMeta):
         else:
             yield from self._suggest_when_file_not_found()
 
-        if self.fix and self.dirty:
+        if self.autofix and self.dirty:
             fuss = self.write_file(file_exists)  # pylint: disable=assignment-from-none
             if fuss:
                 yield fuss
 
-    def init(self):
-        """Hook for plugin initialization after the instance was created."""
+    def post_init(self):
+        """Hook for plugin initialization after the instance was created.
+
+        The name mimics ``__post_init__()`` on dataclasses, without the magic double underscores:
+        `Post-init processing <https://docs.python.org/3/library/dataclasses.html#post-init-processing>`_
+        """
 
     def _suggest_when_file_not_found(self):
         suggestion = self.initial_contents
@@ -106,12 +130,12 @@ class NitpickPlugin(metaclass=abc.ABCMeta):
         logger.info(f"{self}: Suggest initial contents for {self.filename}")
 
         if suggestion:
-            yield self.reporter.make_fuss(SharedViolations.CREATE_FILE_WITH_SUGGESTION, suggestion, fixed=self.fix)
+            yield self.reporter.make_fuss(SharedViolations.CREATE_FILE_WITH_SUGGESTION, suggestion, fixed=self.autofix)
         else:
             yield self.reporter.make_fuss(SharedViolations.CREATE_FILE)
 
     def write_file(self, file_exists: bool) -> Optional[Fuss]:  # pylint: disable=unused-argument,no-self-use
-        """Hook to write the new file when fix mode is on. Should be used by inherited classes."""
+        """Hook to write the new file when autofix mode is on. Should be used by inherited classes."""
         return None
 
     @abc.abstractmethod
@@ -123,12 +147,13 @@ class NitpickPlugin(metaclass=abc.ABCMeta):
     def initial_contents(self) -> str:
         """Suggested initial content when the file doesn't exist."""
 
-    def warn_missing_different(self, comparison: Comparison, prefix: str = "") -> Iterator[Fuss]:
-        """Warn about missing and different keys."""
-        # pylint: disable=not-callable
-        if comparison.missing:
-            yield self.reporter.make_fuss(
-                SharedViolations.MISSING_VALUES, comparison.missing.reformatted, prefix=prefix
-            )
-        if comparison.diff:
-            yield self.reporter.make_fuss(SharedViolations.DIFFERENT_VALUES, comparison.diff.reformatted, prefix=prefix)
+    def write_initial_contents(self, doc_class: Type[BaseDoc], expected_dict: Dict = None) -> str:
+        """Helper to write initial contents based on a format."""
+        if not expected_dict:
+            expected_dict = self.expected_config
+
+        formatted_str = doc_class(obj=expected_dict).reformatted
+        if self.autofix:
+            self.file_path.parent.mkdir(exist_ok=True, parents=True)
+            self.file_path.write_text(formatted_str)
+        return formatted_str
