@@ -31,7 +31,7 @@ class Violations(ViolationEnum):
 
 
 class IniPlugin(NitpickPlugin):
-    """Enforce config on INI files.
+    """Enforce configurations and autofix INI files.
 
     Examples of ``.ini`` files handled by this plugin:
 
@@ -43,14 +43,14 @@ class IniPlugin(NitpickPlugin):
     Style examples enforcing values on INI files: :ref:`flake8 configuration <example-flake8>`.
     """
 
-    can_fix = True
+    fixable = True
     identify_tags = {"ini", "editorconfig"}
     violation_base_code = 320
 
     updater: ConfigUpdater
     comma_separated_values: Set[str]
 
-    def init(self):
+    def post_init(self):
         """Post initialization after the instance was created."""
         self.updater = ConfigUpdater()
         self.comma_separated_values = set(self.nitpick_file_dict.get(COMMA_SEPARATED_VALUES, []))
@@ -122,7 +122,7 @@ class IniPlugin(NitpickPlugin):
         parser = ConfigParser()
         for section in sorted(missing, key=lambda s: "0" if s == TOP_SECTION else f"1{s}"):
             expected_config: Dict = self.expected_config[section]
-            if self.fix:
+            if self.autofix:
                 if self.updater.last_block:
                     self.updater.last_block.add_after.space(1)
                 self.updater.add_section(section)
@@ -141,7 +141,7 @@ class IniPlugin(NitpickPlugin):
 
         yield from self.enforce_missing_sections()
 
-        csv_sections = {v.split(".")[0] for v in self.comma_separated_values}
+        csv_sections = {v.split(SECTION_SEPARATOR)[0] for v in self.comma_separated_values}
         missing_csv = csv_sections.difference(self.current_sections)
         if missing_csv:
             yield self.reporter.make_fuss(
@@ -173,7 +173,7 @@ class IniPlugin(NitpickPlugin):
             return
 
         # Don't change the file if there was a parsing error
-        self.fix = False
+        self.autofix = False
         yield self.reporter.make_fuss(Violations.PARSING_ERROR, cls=parsing_err.__class__.__name__, msg=parsing_err)
         raise Error
 
@@ -181,13 +181,13 @@ class IniPlugin(NitpickPlugin):
         """Enforce missing sections."""
         missing = self.get_missing_output()
         if missing:
-            yield self.reporter.make_fuss(Violations.MISSING_SECTIONS, missing, self.fix)
+            yield self.reporter.make_fuss(Violations.MISSING_SECTIONS, missing, self.autofix)
 
     def enforce_section(self, section: str) -> Iterator[Fuss]:
         """Enforce rules for a section."""
         expected_dict = self.expected_config[section]
         actual_dict = {k: v.value for k, v in self.updater[section].items()}
-        # TODO: add a class Ini(BaseFormat) and move this dictdiffer code there
+        # TODO: add a class Ini(BaseDoc) and move this dictdiffer code there
         for diff_type, key, values in dictdiffer.diff(actual_dict, expected_dict):
             if diff_type == dictdiffer.CHANGE:
                 if f"{section}.{key}" in self.comma_separated_values:
@@ -207,7 +207,7 @@ class IniPlugin(NitpickPlugin):
 
         joined_values = ",".join(sorted(missing))
         value_to_append = f",{joined_values}"
-        if self.fix:
+        if self.autofix:
             self.updater[section][key].value += value_to_append
             self.dirty = True
         section_header = "" if section == TOP_SECTION else f"[{section}]\n"
@@ -216,7 +216,7 @@ class IniPlugin(NitpickPlugin):
             Violations.MISSING_VALUES_IN_LIST,
             f"{section_header}{key} = (...){value_to_append}",
             key=key,
-            fixed=self.fix,
+            fixed=self.autofix,
         )
 
     def compare_different_keys(self, section, key, raw_actual: Any, raw_expected: Any) -> Iterator[Fuss]:
@@ -231,7 +231,7 @@ class IniPlugin(NitpickPlugin):
         if actual == expected:
             return
 
-        if self.fix:
+        if self.autofix:
             self.updater[section][key].value = expected
             self.dirty = True
         if section == TOP_SECTION:
@@ -240,7 +240,7 @@ class IniPlugin(NitpickPlugin):
                 f"{key} = {raw_expected}",
                 key=key,
                 actual=raw_actual,
-                fixed=self.fix,
+                fixed=self.autofix,
             )
         else:
             yield self.reporter.make_fuss(
@@ -249,7 +249,7 @@ class IniPlugin(NitpickPlugin):
                 section=section,
                 key=key,
                 actual=raw_actual,
-                fixed=self.fix,
+                fixed=self.autofix,
             )
 
     def show_missing_keys(self, section: str, values: List[Tuple[str, Any]]) -> Iterator[Fuss]:
@@ -262,14 +262,14 @@ class IniPlugin(NitpickPlugin):
 
         if section == TOP_SECTION:
             yield self.reporter.make_fuss(
-                Violations.TOP_SECTION_MISSING_OPTION, self.contents_without_top_section(output), self.fix
+                Violations.TOP_SECTION_MISSING_OPTION, self.contents_without_top_section(output), self.autofix
             )
         else:
-            yield self.reporter.make_fuss(Violations.MISSING_OPTION, output, self.fix, section=section)
+            yield self.reporter.make_fuss(Violations.MISSING_OPTION, output, self.autofix, section=section)
 
     def add_options_before_space(self, section: str, options: OrderedDict) -> None:
         """Add new options before a blank line in the end of the section."""
-        if not self.fix:
+        if not self.autofix:
             return
 
         space_removed = False
